@@ -19,6 +19,7 @@ from meta.mw import SMWAccess
 from meta.metamodel import Context
 from yprinciple.smw_targets import SMWTarget
 from yprinciple.gengrid import GeneratorGrid
+from yprinciple.genapi import GeneratorAPI
 
 class YPGenApp(App):
     """
@@ -51,7 +52,9 @@ class YPGenApp(App):
         self.wikiUsers=WikiUser.getWikiUsers()
         self.wikiLink=None
         self.contextLink=None
-        self.setSMW(args.wikiId)
+        
+        # see also setGenApiFromWikiId    
+        self.setGenApiFromArgs(args)
         # see https://wiki.bitplan.com/index.php/Y-Prinzip#Example
         self.targets=SMWTarget.getSMWTargets()
         # states
@@ -60,25 +63,35 @@ class YPGenApp(App):
         self.openEditor=State(False)
         self.explainDepth=0
         
-    def setSMW(self,wikiId:str):
+    def setGenApiFromArgs(self,args):
         """
         set the semantic MediaWiki
         """
-        self.smwAccess=SMWAccess(wikiId)
-        self.mw_contexts=self.smwAccess.getMwContexts()
-        self.mw_context=self.mw_contexts.get(self.context_name,None)
-        self.setContext(self.mw_context)
+        self.genapi=GeneratorAPI.fromArgs(args)
+        self.genapi.setWikiAndGetContexts(args.wikiId)
+        self.smwAccess=self.genapi.smwAccess
         if self.wikiLink is not None:
-            self.wikiLink.text=wikiId
-            self.wikiLink.title=wikiId
+            self.wikiLink.text=args.wikiId
+            self.wikiLink.title=args.wikiId
             wikiUser=self.smwAccess.wikiClient.wikiUser
             if wikiUser:
                 self.wikiLink.href=wikiUser.getWikiUrl()
+        self.setMWContext()
+ 
+    def setMWContext(self):
+        """
+        set my context
+        """
+        self.mw_contexts=self.genapi.mw_contexts
+        mw_context=self.mw_contexts.get(self.context_name,None)
+        if mw_context is not None:
+            self.setContext(mw_context)
             
     def setContext(self,mw_context):
         """
         set the Context
         """
+        self.mw_context=mw_context
         if self.contextLink is not None:
             if mw_context is not None:
                 self.contextLink.title=f"{mw_context.context}({mw_context.since} at {mw_context.master}"
@@ -127,7 +140,9 @@ class YPGenApp(App):
         """
         try:
             self.clearErrors()
-            self.setSMW(msg.value)
+            # change wikiUser
+            self.args.wikiId=msg.value
+            self.setGenApiFromArgs(self.args)
             await self.add_or_update_context_select()
             await self.wp.update()
         except BaseException as ex:
